==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE72S.sql <==
/****************************************************************************/
/* GE72 ( ﾌｧｲﾙﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:35                                            */
/****************************************************************************/

CREATE TABLE GE72 (
   SYSTEM_ID        VARCHAR (   10 )                    NOT NULL            /*   1 ｼｽﾃﾑID       */
 , EXECID           VARCHAR (   20 )                    NOT NULL            /*   2 処理ID       */
 , NAME_JA          VARCHAR (  200 )                                        /*   3 名称         */
 , SEQNO            INTEGER                 DEFAULT 0   NOT NULL            /*   4 表示順       */
 , RUNTYPE          VARCHAR (    1 )        DEFAULT '0' NOT NULL            /*   5 実行方法     */
 , RUNPG            VARCHAR (  200 )                                        /*   6 実行ﾌﾟﾛｸﾞﾗﾑ  */
 , CLMS             VARCHAR ( 1000 )                                        /*   7 外部ｶﾗﾑ指定  */
 , PARAMS           VARCHAR ( 4000 )                                        /*   8 ﾊﾟﾗﾒｰﾀ       */
 , DBID             VARCHAR (   20 )                                        /*   9 ﾃﾞｰﾀﾍﾞｰｽID   */
 , TABLE_NAME       VARCHAR (   50 )                                        /*  10 ﾃｰﾌﾞﾙ名      */
 , SHT_NOS          VARCHAR (   50 )                                        /*  11 ｼｰﾄ番号      */
 , FILE_ENC         VARCHAR (   20 )                                        /*  12 ｴﾝｺｰﾄﾞ       */
 , SKIP_CNT         INTEGER                             NOT NULL            /*  13 先頭ｽｷｯﾌﾟ数  */
 , RELEASE_NOTES    VARCHAR (  120 )                                        /*  14 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (   20 )                                        /*  15 設変番号     */
 , UNIQ             BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET            VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET           VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET           VARCHAR (   10 )                                        /* 850 作成者       */
 , DYUPD            VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD            VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD           VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD           VARCHAR (   10 )                                        /* 890 更新者       */
);


CREATE SEQUENCE GE72S00 ;


CREATE TRIGGER GE72T00 FOR GE72
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE72S00,1 );
  END;

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE72S.sql <==
/****************************************************************************/
/* GE72 ( ﾌｧｲﾙﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2020/12/16 08:14:13                                            */
/****************************************************************************/

CREATE TABLE GE72 (
   SYSTEM_ID        VARCHAR (   10 )                    NOT NULL            /*   1 ｼｽﾃﾑID       */
 , EXECID           VARCHAR (   20 )                    NOT NULL            /*   2 処理ID       */
 , NAME_JA          VARCHAR (  200 )                                        /*   3 名称         */
 , SEQNO            INTEGER                 DEFAULT 0   NOT NULL            /*   4 表示順       */
 , RUNTYPE          VARCHAR (    1 )        DEFAULT '0' NOT NULL            /*   5 実行方法     */
 , RUNPG            VARCHAR (  200 )                                        /*   6 実行ﾌﾟﾛｸﾞﾗﾑ  */
 , CLMS             VARCHAR ( 1000 )                                        /*   7 外部ｶﾗﾑ指定  */
 , PARAMS           VARCHAR ( 4000 )                                        /*   8 ﾊﾟﾗﾒｰﾀ       */
 , DBID             VARCHAR (   20 )                                        /*   9 ﾃﾞｰﾀﾍﾞｰｽID   */
 , TABLE_NAME       VARCHAR (   50 )                                        /*  10 ﾃｰﾌﾞﾙ名      */
 , SHT_NOS          VARCHAR (   50 )                                        /*  11 ｼｰﾄ番号      */
 , FILE_ENC         VARCHAR (   20 )                                        /*  12 ｴﾝｺｰﾄﾞ       */
 , SKIP_CNT         INTEGER                             NOT NULL            /*  13 先頭ｽｷｯﾌﾟ数  */
 , RELEASE_NOTES    VARCHAR (  120 )                                        /*  14 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (   20 )                                        /*  15 設変番号     */
 , UNIQ             BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (   14 )                                        /* 820 作成日時     */
 , PGSET            VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET           VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET           VARCHAR (   10 )                                        /* 850 作成者       */
 , DYUPD            VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD            VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD           VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD           VARCHAR (   10 )                                        /* 890 更新者       */
);


CREATE SEQUENCE GE72S00 ;


CREATE TRIGGER GE72T00 FOR GE72
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE72S00,1 );
  END;
